securitysettings/eapqtdialogs/inc/eapfastpacstorepwquerydialog.h
changeset 36 c98682f98478
parent 34 ad1f037f1ac2
child 49 43351a4f2da3
--- a/securitysettings/eapqtdialogs/inc/eapfastpacstorepwquerydialog.h	Thu Jun 24 11:23:08 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapfastpacstorepwquerydialog.h	Fri Jul 09 10:14:51 2010 +0300
@@ -11,23 +11,38 @@
 *
 * Contributors:
 *
 * Description: Fast Pac Store Password Query Dialog
 *
 */
 
 /*
-* %version: 3 %
+* %version: 4 %
 */
 
 #ifndef __EAPFASTPACSTOREPWQUERYDIALOG_H__
 #define __EAPFASTPACSTOREPWQUERYDIALOG_H__
 
+// System includes
 #include <HbInputDialog>
 #include <hbdevicedialoginterface.h>
 
+// User includes
+
+// Forward declarations
 class HbTranslator;
 class EapQtValidator;
 
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_eap_fast_pac_store_pwd_query_dialog
+   @{
+ */
+
+// Class declaration
+
 class EapFastPacStorePwQueryDialog: public HbInputDialog, public HbDeviceDialogInterface
     {
     Q_OBJECT
@@ -38,21 +53,22 @@
         /* Destructor */
         ~EapFastPacStorePwQueryDialog();
         
-        /* Function creates the actual dialog widget */
-        void createDialog( const QVariantMap &parameters );
+        /* Function creates the actual dialog widget. */
+        void createDialog();
         
         /* Device dialog parameters to be set while dialog is displayed.
-         * Not supported.
+         * Not supported. (from HbDeviceDialogInterface)
          */
         bool setDeviceDialogParameters(const QVariantMap &parameters);
         
-        /* Not supported */
+        /* Not supported. (from HbDeviceDialogInterface) */
         int deviceDialogError() const;
         
         /* Closes the device dialog */
         void closeDeviceDialog(bool byClient);
         
-        /* Returns a pointer to this dialog widget */
+        /* Returns a pointer to this dialog widget.
+           (from HbDeviceDialogInterface) */
         HbPopup *deviceDialogWidget() const;
                 
     signals:
@@ -78,24 +94,27 @@
         
         Q_DISABLE_COPY(EapFastPacStorePwQueryDialog)
    
-    private:
-        /* Pointer to the line edit object */
+    private: // data
+        // NOT OWNED
+        //! Pointer to the line edit object
         HbLineEdit *mEdit;
                 
-        /* Pointer to the password validator object */
+        // OWNED        
+        //! Pointer to the password validator object
         QScopedPointer<EapQtValidator> mPwdValidator;
                 
-        /* Pointer to the HbTranslator */
+        //! Pointer to the HbTranslator
         QScopedPointer<HbTranslator> mTranslator;
         
-        /* Pointer to the error message HbTranslator */
+        //! Pointer to the error message HbTranslator
         QScopedPointer<HbTranslator> mErrMsgTranslator;
         
-        /* Tells whether close has already been called for the dialog */
+        //! Tells whether close has already been called for the dialog
         bool mClose;
         
     };
 
+/*! @} */
 
 #endif // __EAPFASTPACSTOREPWQUERYDIALOG_H__
@@ -11,23 +11,38 @@
 * Contributors:
 *
-* Description: Fast Pac Store Password Query Dialog
+* Description: EAP-FAST PAC Store Password Query Dialog
 *
 */
@@ -38,21 +53,22 @@
         int deviceDialogError() const;
         
-        /* Closes the device dialog */
+        /* Closes the device dialog. (from HbDeviceDialogInterface)*/
         void closeDeviceDialog(bool byClient);
         